//
//  AppDelegate.swift
//  galaxy
//
//  Created by davidhuangA on 2023/12/19.
//

import UIKit
import ESTabBarController_swift
import IQKeyboardManagerSwift
import SmartCodable
import GKNavigationBarSwift
import DeviceKit

@main
class AppDelegate: UIResponder, UIApplicationDelegate {
    var window: UIWindow?
    
    func application(_ application: UIApplication, didFinishLaunchingWithOptions launchOptions: [UIApplication.LaunchOptionsKey: Any]?) -> Bool {
        
        // JPush服务注册
        registerJPushService(launchOptions)
        
        //全局导航栏、返回事件/手势
        setupNavBar()
        
        //1.设置主窗口
        setupRootVC()
        
        
        //2.通用UI设置
        setupWholeUI()
        
        //3.其他第三方sdk设置
        thirdSetting()
        
        //4.本地用户信息加载
        YHLoginManager.shared.loadLocalUserInfoData()
        
        //        YHAnalytics.analyticsStart(launchOptions: launchOptions)
        
        
        //        var i = 0
        //        for family: String in UIFont.familyNames {
        //            print("\(i)---项目字体---\(family)")
        //            for names: String in UIFont.fontNames(forFamilyName: family) {
        //                print("== \(names)")
        //            }
        //            i += 1
        //        }
        
        return true
    }
    
    func application(_ app: UIApplication, open url: URL, options: [UIApplication.OpenURLOptionsKey : Any] = [:]) -> Bool {
        if YHAnalytics.handleSchemeUrl(url) ?? false {
            return true
        }
        return true
    }
    
    
    func setupNavBar() {
        GKConfigure.setupDefault()
    }
}


extension AppDelegate {
    
    //
    private func thirdSetting() -> Void {
        DispatchQueue.global().async {
            
            //1.数据解析
#if DEBUG
            SmartConfig.debugMode = .none
#else
            SmartConfig.debugMode = .none
#endif
            
            //2.bugly参数设置
#if DEBUG
            Bugly.start(withAppId: "3b10faa43e")
#else
            Bugly.start(withAppId: "5dc2acc53e")
#endif
            
            
            if !Device.current.isSimulator {
                //3.一键登录
                let handler = TXCommonHandler.sharedInstance()
                handler.setAuthSDKInfo(YhConstant.Alipay.kAliOnePressPhoneLoginKey) { [weak self] dic in
                    
                    guard self != nil else { return }
                    print("Ali Cloud login completed : /(dic） " )
                    
                }
            }
            
        }
    }
    
    //2.通用全局UI设置相关
    private func setupWholeUI() -> Void {
        
        DispatchQueue.global().async {
            //异步延迟设置
            DispatchQueue.main.asyncAfter(wallDeadline: .now() + 0.25) { [] in
                //1、系统控件属性设置
                UITextField.appearance().tintColor = .brandMainColor
                UITextView.appearance().tintColor = .brandMainColor
                
                IQKeyboardManager.shared.enable = true
                IQKeyboardManager.shared.enableAutoToolbar = false
                IQKeyboardManager.shared.resignOnTouchOutside = true  //控制点击背景是否收起键盘
            }
        }
        
        YHNetworkStatusManager.shared.listenNetWorkStatus()
    }
    
    //1.设置主窗口
    private func setupRootVC() {
        let tabBarController = YHTabBarViewController()
        let v0 = YHNavigationController(rootVC:YHHomeViewController())
        let v1 = YHNavigationController(rootVC:YHServiceCenterMainViewController())
        let v2 = YHNavigationController(rootVC:YHMsgViewController())
        let v3 = YHNavigationController(rootVC:YHMyViewController())
        
        v0.tabBarItem = ESTabBarItem.init(YHBasicContentView(),title: "首页", image: UIImage(named: "home"), selectedImage: UIImage(named: "home_1"))
        
        v1.tabBarItem = ESTabBarItem.init(YHBasicContentView(),title: "服务中心", image: UIImage(named: "service"), selectedImage: UIImage(named: "service_1"))
        
        v2.tabBarItem = ESTabBarItem.init(YHBasicContentView(),title: "消息", image: UIImage(named: "msg"), selectedImage: UIImage(named: "msg_1"))
        
        v3.tabBarItem = ESTabBarItem.init(YHBasicContentView(),title: "我的", image: UIImage(named: "me"), selectedImage: UIImage(named: "me_1"))
        
        tabBarController.viewControllers = [v0,v1,v2,v3]
//        tabBarController.viewControllers = [v1,v2] //for test hjl  配合测试同学做自动化测试 Moon 2023.03.12
        tabBarController.tabBar.backgroundColor = .white
        
        
        
        
        
        window = UIWindow(frame: UIScreen.main.bounds)
//        window?.rootViewController = tabBarController
        window?.rootViewController = YHStartPageViewController()
        window?.makeKeyAndVisible()
        
    }
}


